# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DBEndpointForDescribeDBEndpointOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'db_addresses': 'list[DBAddressForDescribeDBEndpointOutput]',
        'endpoint_id': 'str',
        'endpoint_str': 'str',
        'endpoint_type': 'str',
        'network_type': 'str',
        'object_id': 'str',
        'subnet_id': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'db_addresses': 'DBAddresses',
        'endpoint_id': 'EndpointId',
        'endpoint_str': 'EndpointStr',
        'endpoint_type': 'EndpointType',
        'network_type': 'NetworkType',
        'object_id': 'ObjectId',
        'subnet_id': 'SubnetId',
        'vpc_id': 'VpcId'
    }

    def __init__(self, db_addresses=None, endpoint_id=None, endpoint_str=None, endpoint_type=None, network_type=None, object_id=None, subnet_id=None, vpc_id=None, _configuration=None):  # noqa: E501
        """DBEndpointForDescribeDBEndpointOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._db_addresses = None
        self._endpoint_id = None
        self._endpoint_str = None
        self._endpoint_type = None
        self._network_type = None
        self._object_id = None
        self._subnet_id = None
        self._vpc_id = None
        self.discriminator = None

        if db_addresses is not None:
            self.db_addresses = db_addresses
        if endpoint_id is not None:
            self.endpoint_id = endpoint_id
        if endpoint_str is not None:
            self.endpoint_str = endpoint_str
        if endpoint_type is not None:
            self.endpoint_type = endpoint_type
        if network_type is not None:
            self.network_type = network_type
        if object_id is not None:
            self.object_id = object_id
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def db_addresses(self):
        """Gets the db_addresses of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The db_addresses of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: list[DBAddressForDescribeDBEndpointOutput]
        """
        return self._db_addresses

    @db_addresses.setter
    def db_addresses(self, db_addresses):
        """Sets the db_addresses of this DBEndpointForDescribeDBEndpointOutput.


        :param db_addresses: The db_addresses of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: list[DBAddressForDescribeDBEndpointOutput]
        """

        self._db_addresses = db_addresses

    @property
    def endpoint_id(self):
        """Gets the endpoint_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The endpoint_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_id

    @endpoint_id.setter
    def endpoint_id(self, endpoint_id):
        """Sets the endpoint_id of this DBEndpointForDescribeDBEndpointOutput.


        :param endpoint_id: The endpoint_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._endpoint_id = endpoint_id

    @property
    def endpoint_str(self):
        """Gets the endpoint_str of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The endpoint_str of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_str

    @endpoint_str.setter
    def endpoint_str(self, endpoint_str):
        """Sets the endpoint_str of this DBEndpointForDescribeDBEndpointOutput.


        :param endpoint_str: The endpoint_str of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._endpoint_str = endpoint_str

    @property
    def endpoint_type(self):
        """Gets the endpoint_type of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The endpoint_type of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_type

    @endpoint_type.setter
    def endpoint_type(self, endpoint_type):
        """Sets the endpoint_type of this DBEndpointForDescribeDBEndpointOutput.


        :param endpoint_type: The endpoint_type of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._endpoint_type = endpoint_type

    @property
    def network_type(self):
        """Gets the network_type of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The network_type of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._network_type

    @network_type.setter
    def network_type(self, network_type):
        """Sets the network_type of this DBEndpointForDescribeDBEndpointOutput.


        :param network_type: The network_type of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._network_type = network_type

    @property
    def object_id(self):
        """Gets the object_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The object_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this DBEndpointForDescribeDBEndpointOutput.


        :param object_id: The object_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def subnet_id(self):
        """Gets the subnet_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The subnet_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this DBEndpointForDescribeDBEndpointOutput.


        :param subnet_id: The subnet_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def vpc_id(self):
        """Gets the vpc_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501


        :return: The vpc_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this DBEndpointForDescribeDBEndpointOutput.


        :param vpc_id: The vpc_id of this DBEndpointForDescribeDBEndpointOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DBEndpointForDescribeDBEndpointOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DBEndpointForDescribeDBEndpointOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DBEndpointForDescribeDBEndpointOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

import volcenginesdkcore


class VKEApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = volcenginesdkcore.ApiClient()
        self.api_client = api_client

    def create_addon(self, body, **kwargs):  # noqa: E501
        """create_addon  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_addon(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateAddonRequest body: (required)
        :return: CreateAddonResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_addon_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_addon_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_addon_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_addon  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_addon_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateAddonRequest body: (required)
        :return: CreateAddonResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_addon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_addon`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateAddon/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateAddonResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_cluster(self, body, **kwargs):  # noqa: E501
        """create_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cluster(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateClusterRequest body: (required)
        :return: CreateClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_cluster_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_cluster_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_cluster_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_cluster_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateClusterRequest body: (required)
        :return: CreateClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateCluster/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateClusterResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_default_node_pool(self, body, **kwargs):  # noqa: E501
        """create_default_node_pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_default_node_pool(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateDefaultNodePoolRequest body: (required)
        :return: CreateDefaultNodePoolResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_default_node_pool_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_default_node_pool_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_default_node_pool_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_default_node_pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_default_node_pool_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateDefaultNodePoolRequest body: (required)
        :return: CreateDefaultNodePoolResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_default_node_pool" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_default_node_pool`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateDefaultNodePool/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDefaultNodePoolResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_kubeconfig(self, body, **kwargs):  # noqa: E501
        """create_kubeconfig  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_kubeconfig(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateKubeconfigRequest body: (required)
        :return: CreateKubeconfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_kubeconfig_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_kubeconfig_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_kubeconfig_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_kubeconfig  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_kubeconfig_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateKubeconfigRequest body: (required)
        :return: CreateKubeconfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_kubeconfig" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_kubeconfig`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateKubeconfig/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateKubeconfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_node_pool(self, body, **kwargs):  # noqa: E501
        """create_node_pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_node_pool(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNodePoolRequest body: (required)
        :return: CreateNodePoolResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_node_pool_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_node_pool_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_node_pool_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_node_pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_node_pool_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNodePoolRequest body: (required)
        :return: CreateNodePoolResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_node_pool" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_node_pool`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateNodePool/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateNodePoolResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_nodes(self, body, **kwargs):  # noqa: E501
        """create_nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_nodes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNodesRequest body: (required)
        :return: CreateNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_nodes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_nodes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_nodes_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_nodes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateNodesRequest body: (required)
        :return: CreateNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `create_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/CreateNodes/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateNodesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_addon(self, body, **kwargs):  # noqa: E501
        """delete_addon  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_addon(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteAddonRequest body: (required)
        :return: DeleteAddonResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_addon_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_addon_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_addon_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_addon  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_addon_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteAddonRequest body: (required)
        :return: DeleteAddonResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_addon" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_addon`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteAddon/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteAddonResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_cluster(self, body, **kwargs):  # noqa: E501
        """delete_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_cluster(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteClusterRequest body: (required)
        :return: DeleteClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_cluster_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_cluster_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_cluster_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_cluster  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_cluster_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteClusterRequest body: (required)
        :return: DeleteClusterResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_cluster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_cluster`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteCluster/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteClusterResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_kubeconfigs(self, body, **kwargs):  # noqa: E501
        """delete_kubeconfigs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_kubeconfigs(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteKubeconfigsRequest body: (required)
        :return: DeleteKubeconfigsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_kubeconfigs_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_kubeconfigs_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_kubeconfigs_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_kubeconfigs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_kubeconfigs_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteKubeconfigsRequest body: (required)
        :return: DeleteKubeconfigsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_kubeconfigs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_kubeconfigs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteKubeconfigs/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteKubeconfigsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_node_pool(self, body, **kwargs):  # noqa: E501
        """delete_node_pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_node_pool(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteNodePoolRequest body: (required)
        :return: DeleteNodePoolResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_node_pool_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_node_pool_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_node_pool_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_node_pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_node_pool_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteNodePoolRequest body: (required)
        :return: DeleteNodePoolResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_node_pool" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_node_pool`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteNodePool/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteNodePoolResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_nodes(self, body, **kwargs):  # noqa: E501
        """delete_nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_nodes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteNodesRequest body: (required)
        :return: DeleteNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_nodes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_nodes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def delete_nodes_with_http_info(self, body, **kwargs):  # noqa: E501
        """delete_nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_nodes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DeleteNodesRequest body: (required)
        :return: DeleteNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `delete_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/DeleteNodes/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteNodesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forward_kubernetes_api(self, body, **kwargs):  # noqa: E501
        """forward_kubernetes_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forward_kubernetes_api(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ForwardKubernetesApiRequest body: (required)
        :return: ForwardKubernetesApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forward_kubernetes_api_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.forward_kubernetes_api_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def forward_kubernetes_api_with_http_info(self, body, **kwargs):  # noqa: E501
        """forward_kubernetes_api  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forward_kubernetes_api_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ForwardKubernetesApiRequest body: (required)
        :return: ForwardKubernetesApiResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forward_kubernetes_api" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `forward_kubernetes_api`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ForwardKubernetesApi/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ForwardKubernetesApiResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_addons(self, body, **kwargs):  # noqa: E501
        """list_addons  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_addons(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListAddonsRequest body: (required)
        :return: ListAddonsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_addons_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_addons_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_addons_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_addons  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_addons_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListAddonsRequest body: (required)
        :return: ListAddonsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_addons" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_addons`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListAddons/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListAddonsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_clusters(self, body, **kwargs):  # noqa: E501
        """list_clusters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_clusters(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListClustersRequest body: (required)
        :return: ListClustersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_clusters_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_clusters_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_clusters_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_clusters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_clusters_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListClustersRequest body: (required)
        :return: ListClustersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_clusters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_clusters`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListClusters/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListClustersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_kubeconfigs(self, body, **kwargs):  # noqa: E501
        """list_kubeconfigs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_kubeconfigs(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListKubeconfigsRequest body: (required)
        :return: ListKubeconfigsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_kubeconfigs_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_kubeconfigs_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_kubeconfigs_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_kubeconfigs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_kubeconfigs_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListKubeconfigsRequest body: (required)
        :return: ListKubeconfigsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_kubeconfigs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_kubeconfigs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListKubeconfigs/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListKubeconfigsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_node_pools(self, body, **kwargs):  # noqa: E501
        """list_node_pools  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_node_pools(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListNodePoolsRequest body: (required)
        :return: ListNodePoolsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_node_pools_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_node_pools_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_node_pools_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_node_pools  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_node_pools_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListNodePoolsRequest body: (required)
        :return: ListNodePoolsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_node_pools" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_node_pools`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListNodePools/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListNodePoolsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_nodes(self, body, **kwargs):  # noqa: E501
        """list_nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_nodes(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListNodesRequest body: (required)
        :return: ListNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_nodes_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_nodes_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_nodes_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_nodes_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListNodesRequest body: (required)
        :return: ListNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListNodes/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListNodesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_supported_addons(self, body, **kwargs):  # noqa: E501
        """list_supported_addons  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_supported_addons(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListSupportedAddonsRequest body: (required)
        :return: ListSupportedAddonsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_supported_addons_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_supported_addons_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_supported_addons_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_supported_addons  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_supported_addons_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListSupportedAddonsRequest body: (required)
        :return: ListSupportedAddonsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_supported_addons" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_supported_addons`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListSupportedAddons/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListSupportedAddonsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_supported_resource_types(self, body, **kwargs):  # noqa: E501
        """list_supported_resource_types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_supported_resource_types(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListSupportedResourceTypesRequest body: (required)
        :return: ListSupportedResourceTypesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_supported_resource_types_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_supported_resource_types_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_supported_resource_types_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_supported_resource_types  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_supported_resource_types_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListSupportedResourceTypesRequest body: (required)
        :return: ListSupportedResourceTypesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_supported_resource_types" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_supported_resource_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListSupportedResourceTypes/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListSupportedResourceTypesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_tags_for_resources(self, body, **kwargs):  # noqa: E501
        """list_tags_for_resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_tags_for_resources(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListTagsForResourcesRequest body: (required)
        :return: ListTagsForResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_tags_for_resources_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.list_tags_for_resources_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def list_tags_for_resources_with_http_info(self, body, **kwargs):  # noqa: E501
        """list_tags_for_resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_tags_for_resources_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListTagsForResourcesRequest body: (required)
        :return: ListTagsForResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_tags_for_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `list_tags_for_resources`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/ListTagsForResources/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListTagsForResourcesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_resources(self, body, **kwargs):  # noqa: E501
        """tag_resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_resources(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagResourcesRequest body: (required)
        :return: TagResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_resources_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_resources_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def tag_resources_with_http_info(self, body, **kwargs):  # noqa: E501
        """tag_resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_resources_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagResourcesRequest body: (required)
        :return: TagResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `tag_resources`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/TagResources/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagResourcesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def untag_resources(self, body, **kwargs):  # noqa: E501
        """untag_resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.untag_resources(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UntagResourcesRequest body: (required)
        :return: UntagResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.untag_resources_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.untag_resources_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def untag_resources_with_http_info(self, body, **kwargs):  # noqa: E501
        """untag_resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.untag_resources_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UntagResourcesRequest body: (required)
        :return: UntagResourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method untag_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `untag_resources`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/UntagResources/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UntagResourcesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_addon_config(self, body, **kwargs):  # noqa: E501
        """update_addon_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_addon_config(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAddonConfigRequest body: (required)
        :return: UpdateAddonConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_addon_config_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_addon_config_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_addon_config_with_http_info(self, body, **kwargs):  # noqa: E501
        """update_addon_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_addon_config_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAddonConfigRequest body: (required)
        :return: UpdateAddonConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_addon_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `update_addon_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/UpdateAddonConfig/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateAddonConfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_addon_version(self, body, **kwargs):  # noqa: E501
        """update_addon_version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_addon_version(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAddonVersionRequest body: (required)
        :return: UpdateAddonVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_addon_version_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_addon_version_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_addon_version_with_http_info(self, body, **kwargs):  # noqa: E501
        """update_addon_version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_addon_version_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateAddonVersionRequest body: (required)
        :return: UpdateAddonVersionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_addon_version" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `update_addon_version`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/UpdateAddonVersion/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateAddonVersionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_cluster_config(self, body, **kwargs):  # noqa: E501
        """update_cluster_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cluster_config(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateClusterConfigRequest body: (required)
        :return: UpdateClusterConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_cluster_config_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_cluster_config_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_cluster_config_with_http_info(self, body, **kwargs):  # noqa: E501
        """update_cluster_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cluster_config_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateClusterConfigRequest body: (required)
        :return: UpdateClusterConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_cluster_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `update_cluster_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/UpdateClusterConfig/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateClusterConfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_node_pool_config(self, body, **kwargs):  # noqa: E501
        """update_node_pool_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_node_pool_config(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateNodePoolConfigRequest body: (required)
        :return: UpdateNodePoolConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_node_pool_config_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_node_pool_config_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_node_pool_config_with_http_info(self, body, **kwargs):  # noqa: E501
        """update_node_pool_config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_node_pool_config_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateNodePoolConfigRequest body: (required)
        :return: UpdateNodePoolConfigResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_node_pool_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in params or
                                                       params['body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `body` when calling `update_node_pool_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['volcengineSign']  # noqa: E501

        return self.api_client.call_api(
            '/UpdateNodePoolConfig/2022-05-12/vke/post/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateNodePoolConfigResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateNodesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_container_storage_enabled': 'bool',
        'client_token': 'str',
        'cluster_id': 'str',
        'container_storage_path': 'str',
        'initialize_script': 'str',
        'instance_ids': 'list[str]',
        'keep_instance_name': 'bool',
        'kubernetes_config': 'KubernetesConfigForCreateNodesInput'
    }

    attribute_map = {
        'additional_container_storage_enabled': 'AdditionalContainerStorageEnabled',
        'client_token': 'ClientToken',
        'cluster_id': 'ClusterId',
        'container_storage_path': 'ContainerStoragePath',
        'initialize_script': 'InitializeScript',
        'instance_ids': 'InstanceIds',
        'keep_instance_name': 'KeepInstanceName',
        'kubernetes_config': 'KubernetesConfig'
    }

    def __init__(self, additional_container_storage_enabled=None, client_token=None, cluster_id=None, container_storage_path=None, initialize_script=None, instance_ids=None, keep_instance_name=None, kubernetes_config=None, _configuration=None):  # noqa: E501
        """CreateNodesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._additional_container_storage_enabled = None
        self._client_token = None
        self._cluster_id = None
        self._container_storage_path = None
        self._initialize_script = None
        self._instance_ids = None
        self._keep_instance_name = None
        self._kubernetes_config = None
        self.discriminator = None

        if additional_container_storage_enabled is not None:
            self.additional_container_storage_enabled = additional_container_storage_enabled
        if client_token is not None:
            self.client_token = client_token
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if container_storage_path is not None:
            self.container_storage_path = container_storage_path
        if initialize_script is not None:
            self.initialize_script = initialize_script
        if instance_ids is not None:
            self.instance_ids = instance_ids
        if keep_instance_name is not None:
            self.keep_instance_name = keep_instance_name
        if kubernetes_config is not None:
            self.kubernetes_config = kubernetes_config

    @property
    def additional_container_storage_enabled(self):
        """Gets the additional_container_storage_enabled of this CreateNodesRequest.  # noqa: E501


        :return: The additional_container_storage_enabled of this CreateNodesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._additional_container_storage_enabled

    @additional_container_storage_enabled.setter
    def additional_container_storage_enabled(self, additional_container_storage_enabled):
        """Sets the additional_container_storage_enabled of this CreateNodesRequest.


        :param additional_container_storage_enabled: The additional_container_storage_enabled of this CreateNodesRequest.  # noqa: E501
        :type: bool
        """

        self._additional_container_storage_enabled = additional_container_storage_enabled

    @property
    def client_token(self):
        """Gets the client_token of this CreateNodesRequest.  # noqa: E501


        :return: The client_token of this CreateNodesRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_token

    @client_token.setter
    def client_token(self, client_token):
        """Sets the client_token of this CreateNodesRequest.


        :param client_token: The client_token of this CreateNodesRequest.  # noqa: E501
        :type: str
        """

        self._client_token = client_token

    @property
    def cluster_id(self):
        """Gets the cluster_id of this CreateNodesRequest.  # noqa: E501


        :return: The cluster_id of this CreateNodesRequest.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this CreateNodesRequest.


        :param cluster_id: The cluster_id of this CreateNodesRequest.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def container_storage_path(self):
        """Gets the container_storage_path of this CreateNodesRequest.  # noqa: E501


        :return: The container_storage_path of this CreateNodesRequest.  # noqa: E501
        :rtype: str
        """
        return self._container_storage_path

    @container_storage_path.setter
    def container_storage_path(self, container_storage_path):
        """Sets the container_storage_path of this CreateNodesRequest.


        :param container_storage_path: The container_storage_path of this CreateNodesRequest.  # noqa: E501
        :type: str
        """

        self._container_storage_path = container_storage_path

    @property
    def initialize_script(self):
        """Gets the initialize_script of this CreateNodesRequest.  # noqa: E501


        :return: The initialize_script of this CreateNodesRequest.  # noqa: E501
        :rtype: str
        """
        return self._initialize_script

    @initialize_script.setter
    def initialize_script(self, initialize_script):
        """Sets the initialize_script of this CreateNodesRequest.


        :param initialize_script: The initialize_script of this CreateNodesRequest.  # noqa: E501
        :type: str
        """

        self._initialize_script = initialize_script

    @property
    def instance_ids(self):
        """Gets the instance_ids of this CreateNodesRequest.  # noqa: E501


        :return: The instance_ids of this CreateNodesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._instance_ids

    @instance_ids.setter
    def instance_ids(self, instance_ids):
        """Sets the instance_ids of this CreateNodesRequest.


        :param instance_ids: The instance_ids of this CreateNodesRequest.  # noqa: E501
        :type: list[str]
        """

        self._instance_ids = instance_ids

    @property
    def keep_instance_name(self):
        """Gets the keep_instance_name of this CreateNodesRequest.  # noqa: E501


        :return: The keep_instance_name of this CreateNodesRequest.  # noqa: E501
        :rtype: bool
        """
        return self._keep_instance_name

    @keep_instance_name.setter
    def keep_instance_name(self, keep_instance_name):
        """Sets the keep_instance_name of this CreateNodesRequest.


        :param keep_instance_name: The keep_instance_name of this CreateNodesRequest.  # noqa: E501
        :type: bool
        """

        self._keep_instance_name = keep_instance_name

    @property
    def kubernetes_config(self):
        """Gets the kubernetes_config of this CreateNodesRequest.  # noqa: E501


        :return: The kubernetes_config of this CreateNodesRequest.  # noqa: E501
        :rtype: KubernetesConfigForCreateNodesInput
        """
        return self._kubernetes_config

    @kubernetes_config.setter
    def kubernetes_config(self, kubernetes_config):
        """Sets the kubernetes_config of this CreateNodesRequest.


        :param kubernetes_config: The kubernetes_config of this CreateNodesRequest.  # noqa: E501
        :type: KubernetesConfigForCreateNodesInput
        """

        self._kubernetes_config = kubernetes_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateNodesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateNodesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateNodesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CustomerGatewayForDescribeCustomerGatewaysOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'connection_count': 'int',
        'creation_time': 'str',
        'customer_gateway_id': 'str',
        'customer_gateway_name': 'str',
        'description': 'str',
        'ip_address': 'str',
        'project_name': 'str',
        'status': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'account_id': 'AccountId',
        'connection_count': 'ConnectionCount',
        'creation_time': 'CreationTime',
        'customer_gateway_id': 'CustomerGatewayId',
        'customer_gateway_name': 'CustomerGatewayName',
        'description': 'Description',
        'ip_address': 'IpAddress',
        'project_name': 'ProjectName',
        'status': 'Status',
        'update_time': 'UpdateTime'
    }

    def __init__(self, account_id=None, connection_count=None, creation_time=None, customer_gateway_id=None, customer_gateway_name=None, description=None, ip_address=None, project_name=None, status=None, update_time=None, _configuration=None):  # noqa: E501
        """CustomerGatewayForDescribeCustomerGatewaysOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._connection_count = None
        self._creation_time = None
        self._customer_gateway_id = None
        self._customer_gateway_name = None
        self._description = None
        self._ip_address = None
        self._project_name = None
        self._status = None
        self._update_time = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if connection_count is not None:
            self.connection_count = connection_count
        if creation_time is not None:
            self.creation_time = creation_time
        if customer_gateway_id is not None:
            self.customer_gateway_id = customer_gateway_id
        if customer_gateway_name is not None:
            self.customer_gateway_name = customer_gateway_name
        if description is not None:
            self.description = description
        if ip_address is not None:
            self.ip_address = ip_address
        if project_name is not None:
            self.project_name = project_name
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time

    @property
    def account_id(self):
        """Gets the account_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The account_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param account_id: The account_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def connection_count(self):
        """Gets the connection_count of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The connection_count of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: int
        """
        return self._connection_count

    @connection_count.setter
    def connection_count(self, connection_count):
        """Sets the connection_count of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param connection_count: The connection_count of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: int
        """

        self._connection_count = connection_count

    @property
    def creation_time(self):
        """Gets the creation_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The creation_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param creation_time: The creation_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def customer_gateway_id(self):
        """Gets the customer_gateway_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The customer_gateway_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._customer_gateway_id

    @customer_gateway_id.setter
    def customer_gateway_id(self, customer_gateway_id):
        """Sets the customer_gateway_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param customer_gateway_id: The customer_gateway_id of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._customer_gateway_id = customer_gateway_id

    @property
    def customer_gateway_name(self):
        """Gets the customer_gateway_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The customer_gateway_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._customer_gateway_name

    @customer_gateway_name.setter
    def customer_gateway_name(self, customer_gateway_name):
        """Sets the customer_gateway_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param customer_gateway_name: The customer_gateway_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._customer_gateway_name = customer_gateway_name

    @property
    def description(self):
        """Gets the description of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The description of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param description: The description of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def ip_address(self):
        """Gets the ip_address of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The ip_address of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param ip_address: The ip_address of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def project_name(self):
        """Gets the project_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The project_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param project_name: The project_name of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def status(self):
        """Gets the status of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The status of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param status: The status of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501


        :return: The update_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.


        :param update_time: The update_time of this CustomerGatewayForDescribeCustomerGatewaysOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomerGatewayForDescribeCustomerGatewaysOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomerGatewayForDescribeCustomerGatewaysOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CustomerGatewayForDescribeCustomerGatewaysOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class HealthCheckForDescribeListenersOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domain': 'str',
        'enabled': 'str',
        'healthy_threshold': 'int',
        'http_code': 'str',
        'interval': 'int',
        'method': 'str',
        'timeout': 'int',
        'udp_expect': 'str',
        'udp_request': 'str',
        'uri': 'str'
    }

    attribute_map = {
        'domain': 'Domain',
        'enabled': 'Enabled',
        'healthy_threshold': 'HealthyThreshold',
        'http_code': 'HttpCode',
        'interval': 'Interval',
        'method': 'Method',
        'timeout': 'Timeout',
        'udp_expect': 'UdpExpect',
        'udp_request': 'UdpRequest',
        'uri': 'Uri'
    }

    def __init__(self, domain=None, enabled=None, healthy_threshold=None, http_code=None, interval=None, method=None, timeout=None, udp_expect=None, udp_request=None, uri=None, _configuration=None):  # noqa: E501
        """HealthCheckForDescribeListenersOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._domain = None
        self._enabled = None
        self._healthy_threshold = None
        self._http_code = None
        self._interval = None
        self._method = None
        self._timeout = None
        self._udp_expect = None
        self._udp_request = None
        self._uri = None
        self.discriminator = None

        if domain is not None:
            self.domain = domain
        if enabled is not None:
            self.enabled = enabled
        if healthy_threshold is not None:
            self.healthy_threshold = healthy_threshold
        if http_code is not None:
            self.http_code = http_code
        if interval is not None:
            self.interval = interval
        if method is not None:
            self.method = method
        if timeout is not None:
            self.timeout = timeout
        if udp_expect is not None:
            self.udp_expect = udp_expect
        if udp_request is not None:
            self.udp_request = udp_request
        if uri is not None:
            self.uri = uri

    @property
    def domain(self):
        """Gets the domain of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The domain of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this HealthCheckForDescribeListenersOutput.


        :param domain: The domain of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def enabled(self):
        """Gets the enabled of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The enabled of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this HealthCheckForDescribeListenersOutput.


        :param enabled: The enabled of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def healthy_threshold(self):
        """Gets the healthy_threshold of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The healthy_threshold of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: int
        """
        return self._healthy_threshold

    @healthy_threshold.setter
    def healthy_threshold(self, healthy_threshold):
        """Sets the healthy_threshold of this HealthCheckForDescribeListenersOutput.


        :param healthy_threshold: The healthy_threshold of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: int
        """

        self._healthy_threshold = healthy_threshold

    @property
    def http_code(self):
        """Gets the http_code of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The http_code of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._http_code

    @http_code.setter
    def http_code(self, http_code):
        """Sets the http_code of this HealthCheckForDescribeListenersOutput.


        :param http_code: The http_code of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._http_code = http_code

    @property
    def interval(self):
        """Gets the interval of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The interval of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this HealthCheckForDescribeListenersOutput.


        :param interval: The interval of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: int
        """

        self._interval = interval

    @property
    def method(self):
        """Gets the method of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The method of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this HealthCheckForDescribeListenersOutput.


        :param method: The method of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def timeout(self):
        """Gets the timeout of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The timeout of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this HealthCheckForDescribeListenersOutput.


        :param timeout: The timeout of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: int
        """

        self._timeout = timeout

    @property
    def udp_expect(self):
        """Gets the udp_expect of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The udp_expect of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._udp_expect

    @udp_expect.setter
    def udp_expect(self, udp_expect):
        """Sets the udp_expect of this HealthCheckForDescribeListenersOutput.


        :param udp_expect: The udp_expect of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._udp_expect = udp_expect

    @property
    def udp_request(self):
        """Gets the udp_request of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The udp_request of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._udp_request

    @udp_request.setter
    def udp_request(self, udp_request):
        """Sets the udp_request of this HealthCheckForDescribeListenersOutput.


        :param udp_request: The udp_request of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._udp_request = udp_request

    @property
    def uri(self):
        """Gets the uri of this HealthCheckForDescribeListenersOutput.  # noqa: E501


        :return: The uri of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this HealthCheckForDescribeListenersOutput.


        :param uri: The uri of this HealthCheckForDescribeListenersOutput.  # noqa: E501
        :type: str
        """

        self._uri = uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HealthCheckForDescribeListenersOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HealthCheckForDescribeListenersOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HealthCheckForDescribeListenersOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkmongodb.models.account_for_describe_db_accounts_output import AccountForDescribeDBAccountsOutput
from volcenginesdkmongodb.models.account_privilege_for_describe_db_accounts_output import AccountPrivilegeForDescribeDBAccountsOutput
from volcenginesdkmongodb.models.add_tags_to_resource_request import AddTagsToResourceRequest
from volcenginesdkmongodb.models.add_tags_to_resource_response import AddTagsToResourceResponse
from volcenginesdkmongodb.models.allow_list_for_describe_allow_lists_output import AllowListForDescribeAllowListsOutput
from volcenginesdkmongodb.models.associate_allow_list_request import AssociateAllowListRequest
from volcenginesdkmongodb.models.associate_allow_list_response import AssociateAllowListResponse
from volcenginesdkmongodb.models.associated_instance_for_describe_allow_list_detail_output import AssociatedInstanceForDescribeAllowListDetailOutput
from volcenginesdkmongodb.models.config_server_for_describe_db_instance_detail_output import ConfigServerForDescribeDBInstanceDetailOutput
from volcenginesdkmongodb.models.create_allow_list_request import CreateAllowListRequest
from volcenginesdkmongodb.models.create_allow_list_response import CreateAllowListResponse
from volcenginesdkmongodb.models.create_db_endpoint_request import CreateDBEndpointRequest
from volcenginesdkmongodb.models.create_db_endpoint_response import CreateDBEndpointResponse
from volcenginesdkmongodb.models.create_db_instance_request import CreateDBInstanceRequest
from volcenginesdkmongodb.models.create_db_instance_response import CreateDBInstanceResponse
from volcenginesdkmongodb.models.db_address_for_describe_db_endpoint_output import DBAddressForDescribeDBEndpointOutput
from volcenginesdkmongodb.models.db_endpoint_for_describe_db_endpoint_output import DBEndpointForDescribeDBEndpointOutput
from volcenginesdkmongodb.models.db_instance_for_describe_db_instance_detail_output import DBInstanceForDescribeDBInstanceDetailOutput
from volcenginesdkmongodb.models.db_instance_for_describe_db_instances_output import DBInstanceForDescribeDBInstancesOutput
from volcenginesdkmongodb.models.delete_allow_list_request import DeleteAllowListRequest
from volcenginesdkmongodb.models.delete_allow_list_response import DeleteAllowListResponse
from volcenginesdkmongodb.models.delete_db_endpoint_request import DeleteDBEndpointRequest
from volcenginesdkmongodb.models.delete_db_endpoint_response import DeleteDBEndpointResponse
from volcenginesdkmongodb.models.delete_db_instance_request import DeleteDBInstanceRequest
from volcenginesdkmongodb.models.delete_db_instance_response import DeleteDBInstanceResponse
from volcenginesdkmongodb.models.describe_allow_list_detail_request import DescribeAllowListDetailRequest
from volcenginesdkmongodb.models.describe_allow_list_detail_response import DescribeAllowListDetailResponse
from volcenginesdkmongodb.models.describe_allow_lists_request import DescribeAllowListsRequest
from volcenginesdkmongodb.models.describe_allow_lists_response import DescribeAllowListsResponse
from volcenginesdkmongodb.models.describe_availability_zones_request import DescribeAvailabilityZonesRequest
from volcenginesdkmongodb.models.describe_availability_zones_response import DescribeAvailabilityZonesResponse
from volcenginesdkmongodb.models.describe_db_accounts_request import DescribeDBAccountsRequest
from volcenginesdkmongodb.models.describe_db_accounts_response import DescribeDBAccountsResponse
from volcenginesdkmongodb.models.describe_db_endpoint_request import DescribeDBEndpointRequest
from volcenginesdkmongodb.models.describe_db_endpoint_response import DescribeDBEndpointResponse
from volcenginesdkmongodb.models.describe_db_instance_detail_request import DescribeDBInstanceDetailRequest
from volcenginesdkmongodb.models.describe_db_instance_detail_response import DescribeDBInstanceDetailResponse
from volcenginesdkmongodb.models.describe_db_instance_parameters_log_request import DescribeDBInstanceParametersLogRequest
from volcenginesdkmongodb.models.describe_db_instance_parameters_log_response import DescribeDBInstanceParametersLogResponse
from volcenginesdkmongodb.models.describe_db_instance_parameters_request import DescribeDBInstanceParametersRequest
from volcenginesdkmongodb.models.describe_db_instance_parameters_response import DescribeDBInstanceParametersResponse
from volcenginesdkmongodb.models.describe_db_instance_ssl_request import DescribeDBInstanceSSLRequest
from volcenginesdkmongodb.models.describe_db_instance_ssl_response import DescribeDBInstanceSSLResponse
from volcenginesdkmongodb.models.describe_db_instances_request import DescribeDBInstancesRequest
from volcenginesdkmongodb.models.describe_db_instances_response import DescribeDBInstancesResponse
from volcenginesdkmongodb.models.describe_node_specs_request import DescribeNodeSpecsRequest
from volcenginesdkmongodb.models.describe_node_specs_response import DescribeNodeSpecsResponse
from volcenginesdkmongodb.models.describe_regions_request import DescribeRegionsRequest
from volcenginesdkmongodb.models.describe_regions_response import DescribeRegionsResponse
from volcenginesdkmongodb.models.disassociate_allow_list_request import DisassociateAllowListRequest
from volcenginesdkmongodb.models.disassociate_allow_list_response import DisassociateAllowListResponse
from volcenginesdkmongodb.models.instance_parameter_for_describe_db_instance_parameters_output import InstanceParameterForDescribeDBInstanceParametersOutput
from volcenginesdkmongodb.models.modify_allow_list_request import ModifyAllowListRequest
from volcenginesdkmongodb.models.modify_allow_list_response import ModifyAllowListResponse
from volcenginesdkmongodb.models.modify_db_instance_charge_type_request import ModifyDBInstanceChargeTypeRequest
from volcenginesdkmongodb.models.modify_db_instance_charge_type_response import ModifyDBInstanceChargeTypeResponse
from volcenginesdkmongodb.models.modify_db_instance_name_request import ModifyDBInstanceNameRequest
from volcenginesdkmongodb.models.modify_db_instance_name_response import ModifyDBInstanceNameResponse
from volcenginesdkmongodb.models.modify_db_instance_parameters_request import ModifyDBInstanceParametersRequest
from volcenginesdkmongodb.models.modify_db_instance_parameters_response import ModifyDBInstanceParametersResponse
from volcenginesdkmongodb.models.modify_db_instance_ssl_request import ModifyDBInstanceSSLRequest
from volcenginesdkmongodb.models.modify_db_instance_ssl_response import ModifyDBInstanceSSLResponse
from volcenginesdkmongodb.models.modify_db_instance_spec_request import ModifyDBInstanceSpecRequest
from volcenginesdkmongodb.models.modify_db_instance_spec_response import ModifyDBInstanceSpecResponse
from volcenginesdkmongodb.models.mongo_for_describe_db_instance_detail_output import MongoForDescribeDBInstanceDetailOutput
from volcenginesdkmongodb.models.mongos_node_spec_for_describe_node_specs_output import MongosNodeSpecForDescribeNodeSpecsOutput
from volcenginesdkmongodb.models.node_for_describe_db_instance_detail_output import NodeForDescribeDBInstanceDetailOutput
from volcenginesdkmongodb.models.node_spec_for_describe_node_specs_output import NodeSpecForDescribeNodeSpecsOutput
from volcenginesdkmongodb.models.parameter_change_log_for_describe_db_instance_parameters_log_output import ParameterChangeLogForDescribeDBInstanceParametersLogOutput
from volcenginesdkmongodb.models.parameters_object_for_modify_db_instance_parameters_input import ParametersObjectForModifyDBInstanceParametersInput
from volcenginesdkmongodb.models.region_for_describe_regions_output import RegionForDescribeRegionsOutput
from volcenginesdkmongodb.models.remove_tags_from_resource_request import RemoveTagsFromResourceRequest
from volcenginesdkmongodb.models.remove_tags_from_resource_response import RemoveTagsFromResourceResponse
from volcenginesdkmongodb.models.reset_db_account_request import ResetDBAccountRequest
from volcenginesdkmongodb.models.reset_db_account_response import ResetDBAccountResponse
from volcenginesdkmongodb.models.restart_db_instance_request import RestartDBInstanceRequest
from volcenginesdkmongodb.models.restart_db_instance_response import RestartDBInstanceResponse
from volcenginesdkmongodb.models.shard_for_describe_db_instance_detail_output import ShardForDescribeDBInstanceDetailOutput
from volcenginesdkmongodb.models.shard_node_spec_for_describe_node_specs_output import ShardNodeSpecForDescribeNodeSpecsOutput
from volcenginesdkmongodb.models.tag_filter_for_describe_db_instances_input import TagFilterForDescribeDBInstancesInput
from volcenginesdkmongodb.models.tag_for_add_tags_to_resource_input import TagForAddTagsToResourceInput
from volcenginesdkmongodb.models.tag_for_create_db_instance_input import TagForCreateDBInstanceInput
from volcenginesdkmongodb.models.zone_for_describe_availability_zones_output import ZoneForDescribeAvailabilityZonesOutput
